Stan Math Library: stan/math/prim/scal/meta/error_index.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

error_index.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_ERROR_INDEX_HPP
2 #define STAN_MATH_PRIM_SCAL_META_ERROR_INDEX_HPP
3
4 namespace stan {
5
6 struct error_index {
7 enum { value =
8 #ifdef ERROR_INDEX
9 ERROR_INDEX
10 #else
11 1
12 #endif
13 };
14 };
15
16 }
17 #endif
18
stan
Definition: log_sum_exp.hpp:8
stan::error_index::value
Definition: error_index.hpp:7
stan::error_index
Definition: error_index.hpp:6

[ Stan Home Page ] © 2011–2016, Stan Development Team.